Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1001)

Unified Diff: chrome/browser/ui/views/harmony/layout_delegate.h

Issue 2663013003: Rename various LayoutDelegate types/functions for brevity and consistency. (Closed)
Patch Set: Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/harmony/layout_delegate.h
diff --git a/chrome/browser/ui/views/harmony/layout_delegate.h b/chrome/browser/ui/views/harmony/layout_delegate.h
index 548417eff829922654fb40268f39dc6bab4fc2c3..737d56e896a0c01a445c86ff1814472679d7db83 100644
--- a/chrome/browser/ui/views/harmony/layout_delegate.h
+++ b/chrome/browser/ui/views/harmony/layout_delegate.h
@@ -9,7 +9,7 @@
class LayoutDelegate {
public:
- enum class LayoutDistanceType {
+ enum class Metric {
// Horizontal or vertical margin between the edge of a dialog and a
// contained button.
DIALOG_BUTTON_MARGIN,
@@ -23,8 +23,8 @@ class LayoutDelegate {
RELATED_CONTROL_HORIZONTAL_SPACING,
// Vertical spacing between controls that are logically related.
RELATED_CONTROL_VERTICAL_SPACING,
- // Horizontal indent of a subsection relative to related items above, e.g.
- // checkboxes below explanatory text/headings.
+ // Horizontal indent of a subsection relative to related items above, e.g.
+ // checkboxes below explanatory text/headings.
SUBSECTION_HORIZONTAL_INDENT,
// Vertical spacing between controls that are logically unrelated.
UNRELATED_CONTROL_VERTICAL_SPACING,
@@ -32,7 +32,7 @@ class LayoutDelegate {
UNRELATED_CONTROL_VERTICAL_SPACING_LARGE,
};
- enum class DialogWidthType {
+ enum class DialogWidth {
SMALL,
MEDIUM,
LARGE,
@@ -46,8 +46,8 @@ class LayoutDelegate {
// HarmonyLayoutDelegate.
static LayoutDelegate* Get();
- // Returns the requested distance in DIPs.
- virtual int GetLayoutDistance(LayoutDistanceType type) const;
+ // Returns the requested metric in DIPs.
+ virtual int GetMetric(Metric metric) const;
// Returns the alignment used for control labels in a GridLayout; for example,
// in this GridLayout:
@@ -70,9 +70,9 @@ class LayoutDelegate {
// TODO(pkasting): Fix callers and remove this.
virtual bool IsHarmonyMode() const;
- // Returns the preferred width in DIPs for a dialog of the specified |type|.
+ // Returns the preferred width in DIPs for a dialog of the specified |width|.
// May return 0 if the dialog has no preferred width.
- virtual int GetDialogPreferredWidth(DialogWidthType type) const;
+ virtual int GetDialogPreferredWidth(DialogWidth width) const;
private:
DISALLOW_COPY_AND_ASSIGN(LayoutDelegate);

Powered by Google App Engine
This is Rietveld 408576698